.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`future.graph`
===========================
.. automodule:: skimage.future.graph

.. currentmodule:: skimage.future.graph
.. autosummary::

   skimage.future.graph.cut_normalized
   skimage.future.graph.cut_threshold
   skimage.future.graph.merge_hierarchical
   skimage.future.graph.ncut
   skimage.future.graph.rag_boundary
   skimage.future.graph.rag_mean_color
   skimage.future.graph.show_rag

   skimage.future.graph.RAG


cut_normalized
--------------

.. autofunction:: skimage.future.graph.cut_normalized


.. include:: skimage.future.graph.cut_normalized.examples

cut_threshold
-------------

.. autofunction:: skimage.future.graph.cut_threshold


.. include:: skimage.future.graph.cut_threshold.examples

merge_hierarchical
------------------

.. autofunction:: skimage.future.graph.merge_hierarchical


.. include:: skimage.future.graph.merge_hierarchical.examples

ncut
----

.. autofunction:: skimage.future.graph.ncut


.. include:: skimage.future.graph.ncut.examples

rag_boundary
------------

.. autofunction:: skimage.future.graph.rag_boundary


.. include:: skimage.future.graph.rag_boundary.examples

rag_mean_color
--------------

.. autofunction:: skimage.future.graph.rag_mean_color


.. include:: skimage.future.graph.rag_mean_color.examples

show_rag
--------

.. autofunction:: skimage.future.graph.show_rag


.. include:: skimage.future.graph.show_rag.examples


:class:`RAG`
------------


.. autoclass:: RAG
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.future.graph.RAG.examples

